package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.3 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.3) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````J10``#0````X@0````0`!30`(``'
M`"@`%@`5``8````T````-````#0```#@````X`````0````$`````P```!0!
M```4`0``%`$``!@````8````!`````$````!````````````````````[&\`
M`.QO```%```````!``$```#`?0``P'T!`,!]`0!\`@``K!(```8```````$`
M`@```,A]``#(?0$`R'T!`/````#P````!@````0```!1Y71D````````````
M```````````````&````$````%+E=&3`?0``P'T!`,!]`0!``@``0`(```0`
M```!````+VQI8B]L9"UM=7-L+6%R;6AF+G-O+C$`$0```$\````(````"```
M``&````E0`2`*(`0`:"&4("``0``"R`$C3B`$D&*!`@(3P```%````!4````
M60```%H```!@````80```&(`````````9```````````````90```&8```!H
M```````````````!KS3H:G^:?.K3[P[.WD<M;\7?'R[%F[:XC?$.U&34?'94
M/)0A_^0.V7%8'/JA;&#"Y3\LL@&+;^)'Q@%8[Y=YN^.2?%7#/-)GK\QFB`=P
MTT-%U>PS8MOM?ZF<F^"G`@J_VE<;H^#[20``````````````````````````
M"!`````````#``<```````"``0```````P`1``P``````````````!(```#3
M`0`````````````2````%```````````````$0```/D!`````````````!$`
M``!U`0`````````````2````&P``````````````$@```+(!````````````
M`!(````C```````````````2````*@``````````````$@````8"````````
M`````!(```"^`0`````````````2````,P``````````````(````$X#````
M`````````"$```!+```````````````2````40``````````````$@```%@`
M`````````````!(````4`P`````````````2````!0,`````````````$@``
M`(L"`````````````!(```!?```````````````2````+`(`````````````
M$@```&8``````````````!(```#``@`````````````2````;0``````````
M````$@```'4``````````````!(```"I`@`````````````2````?0``````
M````````$@```(,``````````````!(```",```````````````@````_@(`
M````````````$@```*@``````````````!(```"M```````````````2````
M%P(`````````````$0```,<"`````````````!(```!9`@`````````````2
M````)`,`````````````$@```$L"`````````````!(```!R`P``````````
M```2````T@(`````````````$0```$T#`````````````!$```!]`@``````
M```````2````.@,`````````````$@```$\#`````````````!$```"T````
M```````````2````,@,`````````````$@```+T``````````````!$```"#
M`0`````````````2````SP``````````````(@```-X``````````````"``
M``#T```````````````2````]@(`````````````$@```&D"````````````
M`!(```#Y```````````````2````_P``````````````(````+0"````````
M`````!(````9`0`````````````2````HP$`````````````$@```!X!````
M`````````!(```"9`@`````````````2````D@$`````````````$@```"0!
M`````````````!(````U`0`````````````2````)P(`````````````$@``
M`'X``````````````!(````X`@`````````````2````<@(`````````````
M$@```"L#`````````````!(````[`0`````````````2````'`,`````````
M````$@```$\!`````````````!(````B`@`````````````2````X0$`````
M````````$@```%8!`````````````!(```!=`0`````````````2````3`,`
M````````````(0```&X!`````````````!(```!4!```;)`!```````0`!(`
M1P,``!43``"4`0``$@`)`/,!``#%,````@```!(`"@"T`P``)2@``!0&```2
M``D`9`0``(TP```X````$@`)`)$#``#M(P``!````!(`"0##`P``"1````(`
M```2``<`UP,``#DN``!4`@``$@`)`!@$```\@`$``````!``$@!&!```\2,`
M`%@!```2``D`!`0``#R``0``````$``2`*(#``"Y)P``;````!(`"0#!`P``
MI2(``$`````2``D`R0,``&DG``!`````$@`)`/<#``!))0``$@```!(`"0`0
M!```;)`!```````0`!(`7P0``&R0`0``````$``2`%<#``#%%```.````!(`
M"0`F!```6R4``)H````2``D`[0,``#B``0`$````$0`1`#\$```\@`$`````
M`!``$0`)!```J10````````2``D`8`,``*DG```0````$@`)`'L#```M(P``
MP````!(`"0!3!```;)`!```````0`!(`,@0``/4E``!T`0``$@`)``!L:6)P
M97)L+G-O`&]P96YD:7(`<W1D97)R`')E86QL;V,`86-C97-S`'-N<')I;G1F
M`%]?9&5R96=I<W1E<E]F<F%M95]I;F9O`&QS965K`&=E='!I9`!S=')C;7``
M;65M<V5T`'5N;&EN:P!M96UM;W9E`'-T<FYC;7``;'-T870`8VQO<V5D:7(`
M7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`&]P96X`<W1R<W1R`')E861L
M:6YK`%]?<W1A8VM?8VAK7V=U87)D`%]?8WAA7V9I;F%L:7IE`%]?<F5G:7-T
M97)?9G)A;65?:6YF;P!E>&ET`&-L;W-E`%])5$U?<F5G:7-T97)434-L;VYE
M5&%B;&4`<F5A9`!R;61I<@!?7V5R<FYO7VQO8V%T:6]N`&UK9&ER`'!T:')E
M861?9V5T<W!E8VEF:6,`;65M8W!Y`'-T<FQE;@!?7W-T86-K7V-H:U]F86EL
M`&=E='5I9`!097)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S`%!E<FQ?871F
M;W)K7VQO8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A
M:U]N;V-O;G1E>'0`4&5R;%]A=E]S:&EF=`!097)L7W-V7S)P=E]F;&%G<P!?
M9FEN:0!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!03%]T:')?:V5Y
M`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R
M;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]N97=8
M4P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A9&5R
M`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`4$Q?
M;65M;W)Y7W=R87``;&EB8RYM=7-L+6%R;78W+G-O+C$`9G!R:6YT9@!S=')D
M=7``<'1H<F5A9%]A=&9O<FL`<F5A9&1I<@!S<')I;G1F`'-T<F-H<@!S=')T
M;VL`<W1R;F-P>0!?7VQI8F-?<W1A<G1?;6%I;@!?7U]E;G9I<F]N`%]S=&%R
M=%]C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C=7)R96YT7V5X
M96-?<')O8P!P87)?8W5R<F5N=%]E>&5C`'!A<E]S971U<%]L:6)P871H`'!A
M<E]M:W1M<&1I<@!X<U]I;FET`'!A<E]E;G9?8VQE86X`6%-?26YT97)N86QS
M7U!!4E]"3T]4`&UY7W!A<E]P;`!P87)?8F%S96YA;64`7U]B<W-?<W1A<G0`
M7U]E;F1?7P!?7V)S<U]S=&%R=%]?`'!A<E]D:7)N86UE`'!A<E]I;FET7V5N
M=@!?961A=&$`<&%R7V9I;F1P<F]G`%]?8G-S7V5N9%]?`%]E;F0`<&%R7V-L
M96%N=7``+W5S<B]L:6(O<&5R;#4O8V]R95]P97)L+T-/4D4```#`?0$`%P``
M`,1]`0`7````O'\!`!<```#(?P$`%P```-1_`0`7`````(`!`!<````(@`$`
M%P````R``0`7````%(`!`!<````8@`$`%P```!R``0`7````((`!`!<````D
M@`$`%P```"R``0`7````,(`!`!<````X@`$`%P```,!_`0`5!0``Q'\!`!4&
M``#,?P$`%0X``-!_`0`5'P``V'\!`!4C``#<?P$`%2D``.!_`0`5+0``Y'\!
M`!4P``#H?P$`%3(``.Q_`0`5,P``\'\!`!4X``#T?P$`%3T``/A_`0`5/@``
M_'\!`!5#``#$?@$`%@,``,A^`0`6!```S'X!`!8'``#0?@$`%@@``-1^`0`6
M"0``V'X!`!8*``#<?@$`%@L``.!^`0`6#```Y'X!`!8-``#H?@$`%@X``.Q^
M`0`6$```\'X!`!81``#T?@$`%A(``/A^`0`6$P``_'X!`!84````?P$`%A4`
M``1_`0`6%@``"'\!`!87```,?P$`%A@``!!_`0`6&0``%'\!`!8:```8?P$`
M%AL``!Q_`0`6'```('\!`!8=```D?P$`%AX``"A_`0`6(```+'\!`!8A```P
M?P$`%B(``#1_`0`6)```.'\!`!8E```\?P$`%B8``$!_`0`6)P``1'\!`!8H
M``!(?P$`%BL``$Q_`0`6+```4'\!`!8N``!4?P$`%B\``%A_`0`6,0``7'\!
M`!8R``!@?P$`%C,``&1_`0`6-```:'\!`!8U``!L?P$`%C8``'!_`0`6-P``
M='\!`!8Y``!X?P$`%CH``'Q_`0`6.P``@'\!`!8\``"$?P$`%C\``(A_`0`6
M0```C'\!`!9!``"0?P$`%D(``)1_`0`61```F'\!`!9%``"<?P$`%D8``*!_
M`0`61P``I'\!`!9(``"H?P$`%DD``*Q_`0`62@``L'\!`!9+``"T?P$`%DP`
M`+A_`0`63@```;6]Z`%`<$<$X"WE!."?Y0[@C^`(\+[EF&X!``#&C^(6RHSB
MF/Z\Y0#&C^(6RHSBD/Z\Y0#&C^(6RHSBB/Z\Y0#&C^(6RHSB@/Z\Y0#&C^(6
MRHSB>/Z\Y0#&C^(6RHSB</Z\Y0#&C^(6RHSB:/Z\Y0#&C^(6RHSB8/Z\Y0#&
MC^(6RHSB6/Z\Y0#&C^(6RHSB4/Z\Y0#&C^(6RHSB2/Z\Y0#&C^(6RHSB0/Z\
MY0#&C^(6RHSB./Z\Y0#&C^(6RHSB,/Z\Y0#&C^(6RHSB*/Z\Y0#&C^(6RHSB
M(/Z\Y0#&C^(6RHSB&/Z\Y0#&C^(6RHSB$/Z\Y0#&C^(6RHSB"/Z\Y0#&C^(6
MRHSB`/Z\Y0#&C^(6RHSB^/V\Y0#&C^(6RHSB\/V\Y0#&C^(6RHSBZ/V\Y0#&
MC^(6RHSBX/V\Y0#&C^(6RHSBV/V\Y7A'P$8`QH_B%LJ,XLS]O.4`QH_B%LJ,
MXL3]O.4`QH_B%LJ,XKS]O.4`QH_B%LJ,XK3]O.4`QH_B%LJ,XJS]O.4`QH_B
M%LJ,XJ3]O.4`QH_B%LJ,XIS]O.4`QH_B%LJ,XI3]O.4`QH_B%LJ,XHS]O.4`
MQH_B%LJ,XH3]O.4`QH_B%LJ,XGS]O.4`QH_B%LJ,XG3]O.4`QH_B%LJ,XFS]
MO.4`QH_B%LJ,XF3]O.4`QH_B%LJ,XES]O.4`QH_B%LJ,XE3]O.4`QH_B%LJ,
MXDS]O.4`QH_B%LJ,XD3]O.4`QH_B%LJ,XCS]O.4`QH_B%LJ,XC3]O.4`QH_B
M%LJ,XBS]O.4`QH_B%LJ,XB3]O.4`QH_B%LJ,XAS]O.4`QH_B%LJ,XA3]O.4`
MQH_B%LJ,X@S]O.4`QH_B%LJ,X@3]O.4`QH_B%LJ,XOS\O.5X1\!&`,:/XA;*
MC.+P_+SE`,:/XA;*C.+H_+SE`,:/XA;*C.+@_+SE`,:/XA;*C.+8_+SE`,:/
MXA;*C.+0_+SE`,:/XA;*C.+(_+SE`,:/XA;*C.+`_+SE`,:/XA;*C.*X_+SE
M`,:/XA;*C.*P_+SE`,:/XA;*C.*H_+SE<+6(L,WI!A`%D@:I!:H'J$U,__=>
M[TU+?$3C6`.33$L#FN-8$4881@23__?&[DE+XU@>>$A+Y5A^N?_W%.]'2GI$
M$&$0N0$@__=4[__W=N\H:/_WIN^`^%5F*&C_]Z#OD/CN,T/P`@.`^.XS*&C_
M]YCOD/CN,T/P`0.`^.XS!Y@%,+#Q@$\'TS5+-DCC6'A$&48#D__W;.Z``/_W
M1.\&G#%*(6AZ1`%@,$F08'E$06`O20-&>40):(%@+DEY1$#X#!\$(5%@`2$'
MFHI"-=P`(`+Q@$$#,2A-0_@A`"=)`)!]1`,R>40H:?_WENX$1ABY*&G_]PSO
M!$8A37U$*&G_]]#N($AX1`#PT_U@N>MH([D=2'A$`/#,_>A@'$M[1-AH"+$!
M\"G^&DM[1!AI__=*[__W^NT@1@BP<+U4^"%0`3%`^`1?P><`OXAK`0!$`0``
M0`$```P!```@`0```&T!`"0!``"5'0``G&P!`,H?``!L;`$`O1\``&!L`0#I
M#@``1FP!`'$=```8'0``)&P!`!AL`0!/\``+3_``#@-)>41H1B#P#PSE1@#P
M`O@2:0$`'[4)2PE*>T2:6`*2"$J:6`.2`"(!D@=*FU@"'0"3`6@"FP.8__=J
M[NII`0`<`0``!`$``!`!```(2`E+"4IX1'M$@T)Z1(*P!=`'2]-8`9,+L0*P
M&$<"L'!'`+\V:P$`-&L!`*QI`0`8`0``"D@+2WA$>T09&HD0"4H!Z]%Q21!Z
M1(*P!=`'2]-8`9,+L0*P&$<"L'!'`+\$:P$``FL!`'!I`0`X`0``#DL0M7M$
M#DP;>'Q$H[D-2^-8([$,2WM$&&C_]S3N__>W_PI+XU@;L0E(>$3_]WKM`2((
M2WM$&G`0O0"_R&H!`#YI`0`P`0``>FH!`!0!``!.6@``F&H!``BU!TL'2GM$
MFU@KL09)!TAY1'A$__<0[KWH"$"FYP"_ZF@!`#0!``!H:@$`#EH``"WI\$_^
M2_]*U;![1)M8`ZH41@&3&V@`\5P%4Y,`\1P#4_@$&PFZG4)$^`0;^-%`)!%&
M#6I+:P0R:T"-:`EH:T!+0$_J\W,!/--C\=&#:.I)`),#JQQH`FD,1-#X#,`4
M1`":T/@`X(+J#`9":%UH3^JR"19``)H-1(+J"0@(Z@X(3^J^"H;J#`:(Z@((
M942::`3K_F0T1*A$`)Z)Z@H%)4`*1`CK]&@R1$_JM`3>:(7J"0451(KJ!`("
MZ@@"#D1.1(+J"@(%Z_AE,D1/ZK@('FF$Z@@)`NOU8E]I#D0)Z@4)3^JU!;)$
MB>H$"8CJ!0;11!9`!^L!"E1$ANH(!B9$G&D)Z_)I3^JR`H7J`@L,1`;K^6:@
M1`OJ"0O<:4_JN0F"Z@D*B^H%"PKJ!@H,1"Q$PT2*Z@(*"^OV:Z)$3^JV!AQJ
MB>H&"`Q$".H+"`KK^VHB1$_JNPM=:HCJ"0B&Z@L$D$0(Z_IHFFH$Z@H$#41/
MZKH*342+Z@H)=$`)Z@@)"D0R1"Q$B>H+"03K^&211$_JN`C::HKJ"`4)Z_1I
M"D0>:R5`3^JT!)-$B.H$`H7J"@4"Z@D"#D161%U$@NH(`@7K^64R1$_JN0E>
M:X3J"0L"Z_5BGVL.1`OJ!0M/ZK4%L$2+Z@0+B>H%!L-$%D`'ZP$(1$2&Z@D&
M)D3<:POK\FM/ZK("A>H""`Q$!NO[9J%$".H+"!QL3^J["X+J"PJ(Z@4("NH&
M"@Q$+$3(1(KJ`@H(Z_9HHD1/ZK8&7&R+Z@8)#$0)Z@@)"NOX:B)$3^JX")UL
MB>H+"8;J"`211`GK^FG:;`3J"@0-1$_JN@I=1(CJ"@L+Z@D+$40Q1'1`B^H(
M"RQ$BT0=;5Y)!.OY9`U$3^JY"5IMJ$2*Z@D%"^OT:V5`"D1/ZK0$GFVH1))$
MB>H$`@CK^VB"Z@L"#D1/ZKL+DD2Q1-IMA.H+!H;J"`8*Z_AJ"D1/ZK@(L40>
M;A1$B^H(`@GK^FF"Z@H"#D1/ZKH*76X41+-$B.H*!@3K^62&Z@D&#41/ZKD)
MFFZS1*A$BNH)!0OK]&ME0`I$3^JT!*A$DD3=;HGJ!`*"Z@L"".O[:`U$3^J[
M"Y)$&F^I1(3J"P4*Z_AJA>H(!0I$3^JX"!1$B^H(`H+J"@(41%IOJ40)Z_II
M"D1/ZKH*GF^31(CJ"@*"Z@D"!.OY9`Y$3^JY"9-$VF^P1(KJ"08+Z_1K9D`*
M1$_JM`33^(!0L$221(GJ!`((Z_MH@NH+`@U$3^J["Y)$J433^(0@A.H+!87J
M"`4*Z_AJ"D1/ZK@(J433^(A0T_B,8!1$B^H(`@GK^FF"Z@H"#41/ZKH*JT0.
M1(CJ"@441`3K^62P1(7J"04(X`"_F7F"6J'KV6ZV:`$`+`$``-/XD&!/ZKD)
MBNH)`EU$!>OT90Y$8D!/ZK0$LD2)Z@0&;D"R1-/XE&!"1`+K]6(.1$_JM06Q
M1(3J!0960+%$T_B88`KK\FH.1$_JL@(T1(7J`@:&Z@H&-$33^)Q@">OZ:3%$
M3^JZ"@U$@NH*`03K^62!Z@D!3^JY"4KJ"0@-1`CJ!`@*Z@D!T_B@8$CJ`0C]
M207K]&4.1$_JM`0R1$GJ!`N01`OJ!0L)Z@0"2^H""]/XI"`(Z_5H"D1/ZK4%
M4D1$Z@4*!.H%!@KJ"`I*Z@8*T_BH8)-$"^OX:PY$3^JX"$Y$1>H(`K)$`NH+
M`@7J"`8R0]/XK&`*Z_MJ#D1/ZKL+-$1(Z@L&(D0&Z@H&".H+!"9#T_BP0`+K
M^F)/ZKH*#$1+Z@H))40)Z@()"^H*!$GJ!`G3^+1`+D0&Z_)F#$1/ZK("1$1*
MZ@(("NH"!0CJ!@A(Z@4(T_BX4*%$">OV:0U$3^JV!EU$0NH&!*A$!.H)!`+J
M!@4L0]/XO%`(Z_EH#41/ZKD)T_C`<*I$1NH)!51$!>H(!0;J"0H$Z_AD1>H*
M!4_JN`@'ZP$*4D1)Z@@+%40+Z@0+">H(`DOJ`@O3^,0@!>OT94_JM`0*1$CJ
M!`H61`KJ!0H(Z@0"2NH""M/XR""S1`OK]6L*1$_JM05*1$3J!0D$Z@4&">H+
M"4GJ!@G3^,Q@DD0*Z_MJ#D1/ZKL+1D1%Z@L(!>H+`@CJ"@BQ1$CJ`@C3^-`@
M">OZ:4_JN@I+Z@H&"D0B1`;J"08+Z@H$)D/3^-1`D$0(Z_EH#$1/ZKD)+$1*
MZ@D%"NH)`@7J"`4F1!5#T_C8(`;K^&9/ZK@("D1)Z@@$DT0T0`GJ"`(40]/X
MW"!=1`7K]F4*1$_JM@;3^.!PDD1(Z@8"5$0J0`CJ!@H$Z_5D0NH*`D_JM04'
MZP$*T41&Z@4*D40*Z@0*!NH%`DKJ`@K3^.0@">OT:0I$3^JT!$)$T_CH<`KK
M`@A%Z@0"!>H$"@+J"0)"Z@H"!^L!"@CK^6C3^.QP3^JY"59$%D1$Z@D"`NH(
M"CE$!.H)`DKJ`@(-1!5$T_CP$%M*!NOX9A%$3^JX"`Q$B>H(`7%`#$33^/00
M!>OV91%$3^JV!HE$B.H&`6E`B433^/@0!.OU9$_JM0K3^/Q0$41/ZK0+%42(
M1(;J"@$)Z_1I84`N1-/X`$&*Z@L%A>H)!8A$".OY:-/X!!%/ZKD)+D2E&%5$
MB^H)"@;K^&:,&(KJ"`I/ZK@(7$2)Z@@+B^H&"Z-$T_@(0:I$3^JV`0KK]FH4
M1-/X#&&A1(CJ`00+Z_IKA.H*!!9$3^JZ"M/X$%&P1('J"@:&Z@L&H40)Z_MI
ML$1/ZKL+KAC3^!1!#D2*Z@L!@>H)`0CK^6@41$_JN0D.1-/X&!&B1(OJ"00&
MZ_AFA.H(!!%$3^JX"*)$BT33^!Q!B>H(`7%`"NOV:A1$BT1/ZK8!T_@@8:%$
MB.H!!`OK^FN$Z@H$%D1/ZKH*T_@D4;!$@>H*!H;J"P:A1`GK^VFP1$_JNPNN
M&-/X*$$.1(KJ"P&!Z@D!".OY:!1$`^#<O!N/UL%BRD_JN0D.1-/X+!&B1(OJ
M"00&Z_AF$42$Z@@$3^JX"(M$B>H(`7%`BT33^#`1HD0*Z_9J$41/ZK8&B42(
MZ@8!@>H*`8E$T_@T$0OK^FL11$_JN@J(1(;J"@&!Z@L!B$33^#@1T_@\,0GK
M^VD11$_JNPL.1!-$BNH+`0CK^6B!Z@D!<T1/ZKD)FD2+Z@D##D2#Z@@#!NOX
M9E-$`^OV8P-@0V@>1`";1F`#Z[@'#.L)`\-@`VF'8%M$`V$!FU.:&VB:0@'0
M__?8Z56PO>CPCQE++>GP1WM$BD8&1D"S%TJ;6-/X`("X\0`/(]`#1AU&$_@!
M*\JYP4:M&T]&6?@$2X2Q*D8Q1B!&__?(Z``H]-%C73TK\=&GZP@'OQ`!-<KX
M`'`L1"!&O>CPASTJX]#>YP1&]^=$1O7G6E\!`"@!```3M0A+"$I[1)Q8:48C
M:`&3__>^_P&:(VB:0@'0__>,Z0*P$+WJ7@$`+`$``/>U!D9O1@],#TM\1.58
M*V@!DSE&,$;_]Z7_*+D!FBMHFD(-T/_W<ND(2P":XU@;:`/K@@-::$/X!"L`
M*OK1Z.<#L/"]NEX!`"P!```H`0``+>GP3PU&W_@<D4=+^419^`,PA;``DQMH
M!T8#DPMX/2L(OP$U*$;_]T3I`JF`1CA&__=P_P1&D+'_]SKI0$4_TP$\%?@!
M.P3X`3\`*_G1`"``FP.:&VB:0F#0__<PZ3-+6?@#H-KX`+!;^"0P>[DP2Z8<
M>T0::+8`6K$Q1EA&_O?$[\KX``"@N4_P_S#@YP$TZN<!(C!&&F#_]Q;H`9``
M*/+0IO$(`EE&__<4Z`&;RO@`,-KX`#`>1``C1O@$/`*4.T881A/X`2L*L3TJ
M^=$72PCQ`@A9^`-`P!M`1-WX")`F:/[W\N]&^"D``"C,T"-H`II3^"(P&487
M^`$K`?@!*PJQ/2H(T3TB&G`5^`$K`_@!+P`J^=&:YPM&[.<%L+WH\(\`OVA>
M`0`L`0``*`$``*)?`0`MZ?!/+TLP2GM$GUB=L#MH!48;D\"Q`WBSL?[W2N\&
M1I"QW_BH@-_XJ)#?^*B@^$3Y1/I$,$;^]XKO6+DP1O[WR.\H1O_W4.@;FCMH
MFD(VT/_WFN@`\1,$048@1O[W<.\`*.?0248@1O[W:N\`*.'0*$;_]X3H@T8@
M1O_W@.A81`(P_O>([X-&(T8J1E%&__=>Z&E&6$;_]T#H`3!81@O0!)L#]'!#
ML_6`3P71__>H_UA&__<LZ+WG_O=F[_CG';"]Z/"/.%T!`"P!``!3#P``4`\`
M`%$/```PM1-+$TI[1)Q8G;`C:&E&!48;D_[W:N^HN02;`_1P0[/U@$\"T+/U
M($\&T0(A*$;^]_#NL/J`\$`)&YHC:)I"`]#_]S;H`"#WYQVP,+T`OV)<`0`L
M`0``$[4*3`I+?$3C6!AH__<`Z`A+"4GC6'E$`9,(2P&:>T0"L+WH$$#^]^6_
M`+\*7`$`(`$``#P!``!##@``!@X``!.U#$L,2GM$G%@@:/[WX.__]];_(&C^
M]]SO`"('2PA)>T3-Z0`R!TIY1'I$_O>R[@*P$+W*6P$`(`$``(40```-#@``
M)PL``'"U*TLK2GM$GEBM]0!=AK`S:`WU`%(4,A-@_O>P[B9+)DI[1`.L`)-Z
M1`-&0?(!`2!&_O>&[D,<"M$`(QA&#?4`4Q0S&F@S:)I"+=#^]\#OL/6`7P#9
M_]X-]8!5$#4@1D_T@%(I1O[W'.\$'N7;8!S^][3N`T8`*-_0J$("T@(9E4+H
MTZM"`MDJ&9-"X]-!\@$"E$+?W")&&$8I1O[W@.\`(@-&`E7)YPWU`%T&L'"]
M@EL!`"P!``#L#0``V@T``/_WGK\MZ?!/24M*2GM$K?6$79M8@;`$1D=(`Y,-
M]8-2&V@<,GA$#4838/_WU?TO(0=&($;^][;N>+%`2"%&>$3_]PC^#?6#4QPS
M&F@#FR!&&VB:0F;0_O=<[R!&_O=2[S=)@$9Y1"A&_O<H[P9&W_C4D-_XU*#?
M^-2P^43Z1/M$`"[:T#)X`"H(OTY&5[$Q1CA&_O<:[BBY+4EY1/[W#N\&1NWG
M,$;^]R[O`"4P1($;$/@!+2\J%-`(\0$""D2R]8!?NMH?K<WI`+0S1E)&3_2`
M42A&_O?4[0$PL/6`7P+9_]X%<./G!*XQ1BA&_O?8[J"Y,VD#]'!#L_4`3P[1
M`2$H1O[WN.U(N1)(*49X1/_WH?TH1O[W*.X$1I/G#DD`('E$N^<-]81=`;"]
MZ/"/`+^\6@$`+`$``"X-```=#0``!`T``(\,``#%#0``[`P``,X,``!/#```
M2`P```-&$_@!*P*Y<$<O*@B_&$;WYQ"U!$8(L0-X*[D?2'A$O>@00/[W\+W^
M][[N`3@@1(1"`T8=TAIX`3@O*OC0&D82^`$9+RD1T0$[G$(:1@/2$7@!.R\I
M^-`2&Y,<L_6`7QG8`3*R]8!?#MG_WI1"$T;ETYQ"Z-$C>"\K`M$(2'A$SN<(
M2'A$R^<'2R%&>T081O[W_NT0O0`@_.<`OX\+```O"P``B@L``)1:`0!PM4-+
M0TI[1(JPGEAJ1D)),VAY1`F3`?$J!`'Q"@,51AAH66@(,P/%HT(J1O?1&X@Z
M2"N`>$3_]^'\.4@Y3'A$__?<_#A(?$1X1/_WU_PW2'A$__?3_#9(>$3_]\_\
M-4AX1/_WR_PT2'A$__?'_#-(>$3_]\/\($;_]\#\,$AX1/_WO/PO2'A$__>X
M_"Y(>$3_]Y[\`480L2!&__?7_"M(>$3_]Y7\`488L2E(>$3_]\W\*$AX1/_W
MB_P!1GBQ)DAX1/_WP_PE225(>41X1/_WO?P)FC-HFD(8T/[W%NXA2'A$__=U
M_`%&$+$?2'A$Z.<>20HB>40-\1$`_O<8[0`HX=$;2`WQ&P%X1-KG"K!PO;I8
M`0`L`0``P@H``#`+```O"P``90L``"T+```N"P``+0L``#4+``#B"@``,0L`
M`#<+``#-"@``,0L``#`+```V"P``.0L``(H*``!/"P``N0H``!T+``"U"@``
M&@L``)D*```(M0M+>T0;:`$S#-$)2'A$__<D_""Q`'@0L3`X&+\!(`5+>T08
M8`5+>T08:`B]`+^46`$`'PH``'98`0!P6`$`"+7^]Z[M_O?\[`"Q`&@(O?>U
M%D\$1G]$.$;_]__[(48%1@BQ`W@KN1%(>$0#L+WH\$`QY/[WQNRPN2!&_O>$
M[09&*$;^]X#M,$0",/[WB.P&1@A+"$D`E7E$>T0B1O[W7.TQ1CA&X><#L/"]
M40H``#T*``!2"0``+0H``"WI\$^M]0%-F;!8K:7QO`A$1M_XA*7?^(0U^D1:
M^`,PW_A\Y063#?4!0AMH_D1<,A-@#O$0#`[Q!`.E\=0&!T:3Z`<`AN@'`+SH
M#P`/Q)SH`P`.\2@.I?'("83H`P">Z`<`B>@'`-_X/`5X1/_WF/L$1IBQ`WB+
ML?_WC/\@1O[W6.R`1@WU`4-<,QIH!9M`1AMHFD(`\'>"_O<>[?_W<O\$1BBY
M6?@$"T"[W_C\1'Q$($;^]PSM0``!,/[W%.R#1H%&W_CH-`$\>T04^`$O^KE8
M^`1+A+$@1O_W8OL$1@`H]M`#>``K\]#_]Y[\`"COT"!&_O<>[`1&L$8:X/_W
M4/L`*,_0`W@`*\S0_O<2[,?G&49(1@23"?$""?[WP.P$F]/G,$;_]X#\(+$P
M1O[W`.P$1C2Y6/@$:P`N0=`S>``K[]$@1O[WPNP&1EA&_O>^[`9$!O($1C!&
M_O?$ZX%&W_A0--_X4!1[1`"3W_A,-")&>T1Y1,WX!+#^]Y#L3_3@<4A&_O=F
M[`$P'-'^]USL`V@1*Q?0W_@D-#QH6O@#,!MH!)/^]U#LW_@8%`-H(D8`DWE$
M2T8$F/[W'.Q/\``(8><T1K[G#?$@"$%&2$;^]Z+K!$90L?E+^TE:^`,`.FA+
M1GE$`&C^]P3LY^?8^!`P`_1P0[/U@$_MT=CX&+#^]W+L@T7GT=CX$###\P@#
ML_7@?^#1,$;^]V;K@$;K2'A$__>_^@`H>=$^:#!&_O=0[`,H@D8>V>5)!#AY
M1#!$_O<HZ[BYNO$$#P30LD0:^`4\+RL/T7]H;[$X1O[W..P#*`C9VTD$.'E$
M.$3^]Q+K`"@(OSY&__=G_@20`"A`\$^!`48P1O[W7.N"1@`H`/!'@0(D3_#_
M,V_P$0(`E"X?_O?LZ@8B,4901O[WO.L5^`0\`"L_T7-X0RL\T;-X02LYT?-X
M0RLVT3-Y2"LST7-Y12LPT4_P_S-O\#D"`)101O[WS.HI(C%&4$;^]YSK2D:Y
M2[I)>T3-Z0!CN4MY1'M$0$;^]\[K2$;^]ZKKM4A!1GA$__>%^D!&__<^_K3F
M/FC^]PCK`48P1O_W4OP&1@`H?_1\KWGG`"<`(P"7`")01O[WG.J32Z7QI`1%
M^*0\`_&(,V-@`_$I0Z/UEA.C]HMCHV"C\8@SXV"+2Z=AQ.D$-Z7Q2`/G90:3
M3_0`0C%&4$;^]U#K!QY:W%!&_O=`ZX`A8VFF:1^ZP_/%`UH<I?&("C@J-KH*
M^`,0"NL"`$#SM(#"\4`"`"'^]X;J($;^]PK]."(`(5!&_O=^ZL3I%6<@1O[W
M`/U5^*0\@T\:ND7X1"QB:*7Q1`,2ND7X0"RB:#`]$KI%^`PLXFA_1!*Z1?@(
M+")I'$82ND7X!"PN1BA&%/@!*SE&_O=$ZP2;`C4!,Q0K!)/ST0`CAO@H,'!+
M<$E[1,WI`&-O2TI&>T1Y1&#G8VGZ`)L8*+^B:6-A)+\!,J)AHVD#ZU=SHV'C
M;0`K6M##\4`+I?&(`+M%&$2HO[M&L$(#T@#K"P.>0@73L$($V0;K"P.80@#2
M_]Z[]0!/^]A:1C%&_O<,Z^-M6T1`*^-E?_1KKR!&I^L+![-$_O>3_%E&I?&(
M"Q7@644"V0:;F4+BTUE%`?%``P'2FT7<TT`B6$8'D_[W[.H@1O[W?/P'FT`_
M&48_+^?<I?&(`YE"`MD[1)E"R-.E\8@#F4("TLH9DT+!TT0OO]@Z1J7QB`#^
M]\[JYV4QY[-&RN?"\3@"`"%2YS5)-DAY1'A$__=Z^?[WK.DS2S1)>T3-Z0`#
M,TM*1GM$>41`1O[WK.HP33%.,4]]1'Y$?T1/].!Q0$;^]WSJ`3!_]-&N_O=P
MZ@-H$2M_],NN_O>*Z0$T`)#-Z0%'*T9*1C%&0$;^]XSJY.<-]0%-&;"]Z/"/
M`2-%9_#ATL-V5@$`+`$``+!7`0"P"```30D``#H)``"J"```E0@``,('```(
M`0``90@``'`(``#:!P``:P@``$0(``!U"```M0<``#@&```.!@``#@8``#L'
M``!W!@``_@0``,D$``!/!```-08``(`%``#X`P``Z`,``'X%```7!@``+>GX
M3X!+@4I[1)Q8(&C^]S;J!48@:/[W,NJ5^&0P@/AE,'M(>$3_]['X(+$#>#$K
M`=%#>`NQ__?!^R!H_O<>ZG1)"R,!(GE$_O>`Z3B[(&C^]Q3J<$D#(P$B>43^
M]W;I!48`*&31(&C^]PCJ:TD#(P$B>43^]VKI!48`*'W0:$AX1/_W@_@&1@`H
M9]`@:/[W]NDR1NMH&6C^]V3I;>`!)<-HW_B`D9]IW_A\H?E$V?@$,`7Q_SBK
M0B!H"-W^]][I`"-"1CE&_O?LZ`9&0+E72WM$6F@!.I!%N=$!)AU&(N#9^`@P
M`FA3^"6PDV@*Z@,#L_6`;P?1T6A81O[WP.@`*.71`373YR!H_O>XZ3%H`B,`
M(O[WS.D!1N[G_O>PZ3E&_O=JZ`$V:V@@:+-"]=R.YR!H_O>DZ>MH/4H9:'I$
M_O<2Z>MH&VB;:%L"C-4@:/[WENGK:!EH_O>PZ(3G__?*^09&(&B6L_[WBNGK
M:#)&&6C^]_CH,$;^]VCI(&C^]W[I!48@:/[W>NDJ20$B>43^]T;H*4H!1GI$
M*$;^]^3H(&C^]VSI`".`^&4P)$@D3'A$_O?L_WQ$X&"`N:!H__<6_.!@6+D?
M2'A$_O=`Z/[W5ND=2WM$FFCK:!)H7.<;3$_TX'%\1.!H_O<JZ1$H`T8)T$(<
M`2H&V19(U.D"$@EH>$3^]R3HO>CXCW10`0`@`0``'0,``($$``!R!```800`
M`(\"``!P40$```0@`$Q1`0"2`P``20,``%0#``!8`0``:%`!`"H#``!*4`$`
M.E`!`!,#```XM01&__=C^O_W6/H%1O_W9?MPL6RQ(WA;L09)*$9Y1/[W7NB%
M0@31($:]Z#A`__=;N#B]B@$```&UO>@!0'!'<&5R;'AS:2YC`%]?14Y67U!!
M4E]#3$5!3E]?("`@("`@("`@("`@("`@```N+@`E<R\E<P!$>6YA3&]A9&5R
M.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`+W!R;V,O
M)6DO)7,`97AE`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`
M4$523$Q)0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]3
M4$%73D5$`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"
M04Q?1$5"54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/
M0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]`#$`3$1?3$E"
M4D%265]0051(`%-94U1%30`E,#)X`"5S)7,E<R5S`'!A<BT`)7,Z(&-R96%T
M:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\]
M)6DI"@`E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP
M;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*`'!A
M<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E<R5S=&5M<"TE=25S`"5S)7-T96UP
M+25U+25U)7,`05)'5@`8`'!E<FP`,`!005(Z.E!A8VME<CHZ5D524TE/3@`Q
M+C`T-P!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0`E<SH@8W)E
M871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D
M("AE<G)N;STE:2D*`"UE`"TM`%5315(`55-%4DY!344`5$5-4$1)4@!435``
M+W1M<`!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B
M?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA
M9V4@7U]P87)?<&P["FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I
M;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL
M93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE
M.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H
M)'!A<E]T96UP*3L*;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T
M96UP(GTI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@
M<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP
M.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@
M)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G
M+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-5
M1D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C
M(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F
M("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB
M<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N
M("1T;7`M/F9I;&5N86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE
M;F%M93L*;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL
M(#(^)C$@)B<["F-L;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3
M<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z
M("D*+B`D=&UP+3YF:6QE;F%M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS
M.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/
M5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[
M4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T:%]S97`@("`@/3X@*"1>
M3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D
M7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL
M"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z
M("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM
M>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%2
M3E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA
M<W0["F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O
M9VYA;64["FUY("1O9F9S970@/2`U,3(["FUY("1I9'@@/2`M,3L*=VAI;&4@
M*#$I"GL*)&]F9G-E="`]("1S:7IE(&EF("1O9F9S970@/B`D<VEZ93L*<V5E
M:R!?1D@L("TD;V9F<V5T+"`R(&]R(&1I92!Q<5MS965K(&9A:6QE9"!O;B`B
M)'!R;V=N86UE(CH@)"%=.PIM>2`D;G)E860@/2!R96%D(%]&2"P@)&)U9BP@
M)&]F9G-E=#L*9&EE('%Q6W)E860@9F%I;&5D(&]N("(D<')O9VYA;64B.B`D
M(5T@=6YL97-S("1N<F5A9"`]/2`D;V9F<V5T.PHD:61X(#T@<FEN9&5X*"1B
M=68L(")<;E!!4BYP;5QN(BD["FQA<W0@:68@)&ED>"`^/2`P('Q\("1O9F9S
M970@/3T@)'-I>F4@?'P@)&]F9G-E="`^(#$R."`J(#$P,C0["B1O9F9S970@
M*CT@,CL*?0IL87-T('5N;&5S<R`D:61X(#X](#`["B1O9F9S970@+3T@)&ED
M>"`M(#0["G-E96L@7T9(+"`M)&]F9G-E="P@,CL*<F5A9"!?1D@L("1B=68L
M(#0["G-E96L@7T9(+"`M)&]F9G-E="`M('5N<&%C:R@B3B(L("1B=68I+"`R
M.PIR96%D(%]&2"P@)&)U9BP@-#L*)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M
M(#0["FUY("5R97%U:7)E7VQI<W0["G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@
M>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B
M3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q*%5N<&%C
M:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["FUY("1C<F,@/2`H("1F=6QL
M;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY
M("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH
M7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U
M;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@
M(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]T
M96UP9FEL92@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ
M.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@
M*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[
M4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1B87-E
M;F%M921E>'0B+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z("1F:6QE;F%M
M95QN(BD["GT*96QS92!["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B10
M05(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@
M)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PI]"G)E
M860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S
M96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@
M(21M;V1U;&4["FUY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T
M>R1M;V1U;&5]('Q\(&1O('L*;7D@)&ME>3L*9F]R96%C:"`H:V5Y<R`E<F5Q
M=6ER95]L:7-T*2!["FYE>'0@=6YL97-S("]<421M;V1U;&5<120O.PHD:V5Y
M(#T@)%\[(&QA<W0["GT*9&5L971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@
M9&5F:6YE9"@D:V5Y*3L*?2!O<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B
M+VQO861E<B\D9FEL96YA;64O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!
M3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/
M.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*
M<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*
M<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE
M*"(D9FEL96YA;64M/GMC<F-]+G!M(BP@)&9I;&5N86UE+3Y[8G5F?2D["F]P
M96X@;7D@)&9H+"`G/"<L("1F:6QE;F%M92!O<B!D:64@(F-A;B=T(')E860@
M)&9I;&5N86UE.B`D(2(["F)I;FUO9&4H)&9H*3L*<F5T=7)N("1F:#L*?0ID
M:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE
M(5QN(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2
M.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E
M<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q
M=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME
M>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M
M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@
M/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*
M9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI
M>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65]
M.PI]"FQA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PHD<W1A<G1?
M<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U
M="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6
M>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S
M96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$
M14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R
M+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@
M(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A
M<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N
M9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[
M4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M
M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'
M5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O
M<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R
M.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I
M9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I
M9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G
M*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD
M8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@
M/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L
M("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*?0IE;'-I
M9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%2
M1U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%
M3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T
M.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2
M.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI
M9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I
M<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1P87(@
M/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*
M07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H,3(X*C$P,C0I.PIO<&5N(&UY
M("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D
M(2(["F)I;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II
M<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA
M;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R
M(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E96YV(#T@9&\@
M>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G3454
M02YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@
M<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*
M?0I].PIL;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@
M4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["F)I;FUO9&4H4$%2
M*3L*9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@
M97$@(E!+7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@
M/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@
M24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP
M-S<W+`HI(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]("AD969I;F5D
M("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["G-E96L@7T9(+"`P
M+"`P.PIM>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H(21%3E9[4$%2
M7U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*
M<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0
M;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I"GT*9F]R96%C:"!M
M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y
M?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=
M+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B
M.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A
M9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@
M*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN
M="@D;&]A9&5R*3L*)"\@/2!U;F1E9CL*:68@*"1B=6YD;&4I('L*<F5Q=6ER
M92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D[
M"FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E
M<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R
M"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE
M("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*;7D@)69I
M;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?
M;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ
M0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*9F]R96%C:"`H<V]R="!K
M97ES("5F:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE*3L*9F]R96%C:"!M>2`D
M9&ER("A`:6YC*2!["FEF("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA<W0["GT*96QS:68@*"]>*%Q1)&1I
M<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L("1N86UE*2`]("@D,2P@
M)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=
M*5Q:(2D@>PII9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H
M97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]
M"F5L<VEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D
M:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@
M)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F
M*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["F]U=',H
M(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[
M;F%M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@)&-O;G1E;G0["FEF("AR
M968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@
M>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F
M:6QE.B`D(2(["F)I;FUO9&4H1DE,12D["B1C;VYT96YT(#T@/$9)3$4^.PIC
M;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH
M7"1C;VYT96YT+"`D9FEL92D*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@
M)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T
M8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE
M*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT
M*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@
M*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E
M.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"BDI.PHD9F@M
M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I
M;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H
M*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@
M,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T
M*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T
M.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER
M92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![
M(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@
M)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]
M('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R
M<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D;W5T+"`B8B(I(&EF
M("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B
M/"1O=70B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*
M8VQO<V4H)&9H*3L*?0I]"B1C86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE
M>&1I9V5S="`Z("1M=&EM93L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q
M("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%
M(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G
M3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT
M*")<;E!!4BYP;5QN(BD["B1F:"T^8VQO<V4["F-H;6]D(#`W-34L("1O=70[
M"F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F
M:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET
M7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@
M07)C:&EV93HZ6FEP.PI]"FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*)&9H+3YF9&]P96XH9FEL96YO*%]&
M2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PHD>FEP+3YR96%D1G)O;49I;&5(
M86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH
M*2!O<B!D:64@(B0A.B`D0"(["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`[
M"B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A
M)$5.5GM005)?1$5"54=].PIO=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D
M14Y6>U!!4E]414U0?2(I*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI
M('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@
M)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^
M:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.
M86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB
M+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ
M0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T
M7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I
M;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E
M<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H
M*2D@>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET
M(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PI](&5L<V4@>PIO
M=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA
M;64B*2D["B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE
M*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*
M?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*
M9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A
M<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G
M<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD
M14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!
M4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q
M=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E
M>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ
M)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D
M<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R
M<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U
M:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I
M8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#
M87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U
M:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER
M92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P
M96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E
M($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E
M<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E(%!!4CL*
M<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER
M92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z
M.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q
M=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E
M<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z
M.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA
M;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@
M4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U
M8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@
M86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D
M,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]
M+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*
M<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D
M("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M
M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I
M9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M
M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF
M("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS
M92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@
M?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G.PIM>2`D<W1M
M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB
M+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D14Y6
M>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI
M6SE=*2!["F]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I.PIS965K("1F
M:"P@+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*:68@*"1B=68@
M97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G-Y<W)E860@)&9H
M+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I<B`N/2`B)$-O
M;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["GT*96QS92!["FUY("1C='@@
M/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE
M=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T
M.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@
M1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@
M)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO
M;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X
M+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D["GT*96QS92![
M"FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@>PIB
M:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*
M?0I]"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@*"`D
M8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["GT*8VQO<V4H)&9H
M*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T;7!D:7(@+CT@
M(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%27U1%35!](#T@
M)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T.PI]"B1P87)?
M=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0
M?2`]?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL92!["FUY("@D;F%M92P@)&-O
M;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M
M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M
M92`]("(D9G5L;&YA;64N)"0B.PIO<&5N(&UY("1F:"P@)SXG+"`D=&5M<&YA
M;64@;W(@9&EE(")C86XG="!W<FET92`D=&5M<&YA;64Z("0A(CL*8FEN;6]D
M92`D9F@["G!R:6YT("1F:"`D8V]N=&5N=',["F-L;W-E("1F:#L*8VAM;V0@
M)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E
M;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E
M='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F
M:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%
M?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\
M/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L
M("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D
M<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@
M*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O
M9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D
M9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@
M*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PHD<')O9VYA;64@+CT@
M)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS
M<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN
M97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6
M>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\[
M"B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D
M0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L
M:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D
M:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D
M:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O
M9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345]
M.PII9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@
M>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*
M;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W
M9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#
M=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH
M/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI
M;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P
M87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T]
M(#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141]
M(#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#
M2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*9&5L971E("1%3E9[)U!!
M4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O
M*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@
M:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@)'!A<E]C
M;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["FEF
M("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]
M"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*;7D@
M)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!
M3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%2
M7T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE
M=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@
M>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O
M;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#
M;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H
M97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*
M?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF
M4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q
M*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@
M3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0IU;FQE<W,@+64@)'!R;V=N
M86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>
M7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%
M4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T52
M4D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@
M:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````#%%0``;14```$````!`````0```.$"```/````
M<`0```P````)$```#0```,4P```9````P'T!`!L````$````&@```,1]`0`<
M````!````/7^_V\L`0``!0```)@(```&````"`(```H```".!```"P```!``
M```5``````````,```"X?@$``@```/`!```4````$0```!<````8#@``$0``
M`"@-```2````\````!,````(````&`````````#[__]O`0``"/K__V\0````
M`````````````````````````````````````````````````````,A]`0``
M`````````!`0```0$```$!```!`0```0$```$!```!`0```0$```$!```!`0
M```0$```$!```!`0```0$```$!```!`0```0$```$!```!`0```0$```$!``
M`!`0```0$```$!```!`0```0$```$!```!`0```0$```$!```!`0```0$```
M$!```!`0```0$```$!```!`0```0$```$!```!`0```0$```$!```!`0```0
M$```$!```!`0```0$```$!```!`0```0$```$!```!`0```0$```$!```!`0
M```0$```$!```!`0```0$```$!```!`0```0$```%1,`````````````Q3``
M````````````"1``````````````````````````````````````````````
M````````````@`$`_____ZXS``#Y,````````-HQ``#3,0``HC,``/`Q``"J
M,P```````)0S``"9,P```````+,S``!'0T,Z("A!;'!I;F4@."XR+C`I(#@N
M,BXP`$$R````865A8FD``2@````%-RU!``8*!T$(`0D""@02!!,!%`$5`1<#
M&`$:`AP!'@0B`0`N<VAS=')T86(`+FEN=&5R<``N9VYU+FAA<V@`+F1Y;G-Y
M;0`N9'EN<W1R`"YR96PN9'EN`"YR96PN<&QT`"YI;FET`"YT97AT`"YF:6YI
M`"YR;V1A=&$`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD
M>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N=``N05)-+F%T=')I8G5T
M97,`````````````````````````````````````````````````````````
M"P````$````"````%`$``!0!```8```````````````!`````````!,```#V
M__]O`@```"P!```L`0``W`````,`````````!`````0````=````"P````(`
M```(`@``"`(``)`&```$`````P````0````0````)0````,````"````F`@`
M`)@(``".!``````````````!`````````"T````)`````@```"@-```H#0``
M\`````,`````````!`````@````V````"0```$(````8#@``&`X``/`!```#
M````$`````0````(````/P````$````&````"!````@0```(````````````
M```"`````````#H````!````!@```!`0```0$```!`,`````````````!```
M``0```!%`````0````8````4$P``%!,``+`=``````````````0`````````
M2P````$````&````Q#```,0P```(```````````````"`````````%$````!
M`````@```,PP``#,,```&S\``````````````0````````!9`````0````(`
M``#H;P``Z&\```0```````````````0`````````8P````X````#````P'T!
M`,!]```$```````````````$````!````&\````/`````P```,1]`0#$?0``
M!```````````````!`````0```![````!@````,```#(?0$`R'T``/`````$
M``````````0````(````A`````$````#````N'X!`+A^``!(`0``````````
M```$````!````(D````!`````P````"``0``@```/```````````````!```
M``````"/````"`````,````\@`$`/(```#`0``````````````0`````````
ME`````$````P`````````#R````:```````````````!`````0```)T````#
M``!P``````````!6@```,P```````````````0`````````!`````P``````
>````````B8```*T```````````````$`````````
